@@ -1,3 +1,17 @@
+/* enable mremap on GNU/Linux */
+#ifdef __linux__
+# define _GNU_SOURCE
+#endif
+
+/* enable the POSIX prototypes of mmap/munmap on Solaris */
+#ifdef __sun
+# if __STDC_VERSION__ >= 199901L
+#  define _XOPEN_SOURCE 600
+# else
+#  define _XOPEN_SOURCE 500
+# endif
+#endif
+
 #include "emman.h"
 
 #include <ecb.h>
@@ -8,11 +22,8 @@
 # include <unistd.h>
 #endif
 
-#if  _POSIX_MAPPED_FILES
+#if _POSIX_MAPPED_FILES > 0
 # define USE_MMAP 1
-# ifdef __linux__
-#  define _GNU_SOURCE
-# endif
 # include <sys/mman.h>
 # ifndef MAP_FAILED
 #  define MAP_FAILED ((void *)-1)
@@ -34,6 +45,7 @@ static uint32_t pagesize;
 # endif
 #else
 # define PAGESIZE 1
+# define BOOT_PAGESIZE
 #endif
 
 size_t
