@@ -1,7 +1,6 @@
 #ifndef RXVT_UTIL_H
 #define RXVT_UTIL_H
 
-#include <new>
 #include <stdlib.h>
 #include <string.h>
 #include "ecb.h"
@@ -25,8 +24,6 @@ template<typename T, typename U> static inline void max_it (T &a, U b) { a = a >
 template<typename T, typename U, typename V> static inline T    clamp    (T  v, U a, V b) { return v < (T)a ? a : v >(T)b ? b : v; }
 template<typename T, typename U, typename V> static inline void clamp_it (T &v, U a, V b) {    v = v < (T)a ? a : v >(T)b ? b : v; }
 
-template<typename T> static inline T squared_diff (T a, T b) { return (a - b) * (a - b); }
-
 // linear interpolation
 template<typename T, typename U, typename P>
 static inline T
@@ -89,80 +86,7 @@ struct rxvt_vec : simplevec<void *>
 };
 #endif
 
-inline void *
-operator new (size_t size)
-{
-  // TODO: use rxvt_malloc
-  return malloc (size);
-}
-
-inline void
-operator delete (void *p)
-{
-  free (p);
-}
-
-template<typename T>
-struct auto_ptr
-{
-  T *p;
-
-  auto_ptr ()     : p (0) { }
-
-  explicit
-  auto_ptr (T *a) : p (a) { }
-
-  auto_ptr (auto_ptr &a)
-  {
-    p = a.p;
-    a.p = 0;
-  }
-
-  template<typename A>
-  auto_ptr (auto_ptr<A> &a)
-  {
-    p = a.p;
-    a.p = 0;
-  }
-
-  ~auto_ptr ()
-  {
-    delete p;
-  }
-
-  void reset (T *a)
-  {
-    delete p;
-    p = a;
-  }
-
-  // void because it makes sense in our context
-  void operator =(auto_ptr &a)
-  {
-    reset (a.release ());
-  }
-
-  template<typename A>
-  void operator =(auto_ptr<A> &a)
-  {
-    reset (a.release ());
-  }
-
-  T *operator ->() const { return p; }
-  T &operator *() const { return *p; }
-
-  operator T *()  { return p; }
-  T *get () const { return p; }
-
-  T *release()
-  {
-    T *r = p;
-    p = 0;
-    return r;
-  }
-};
-
-typedef auto_ptr<char> auto_str;
+typedef estl::scoped_array<char> auto_str;
 
 #endif
 
